==> mm_excel-1.1.2.tgz: package/test.js <==
const Excel = require('./index.js');

var config = {
	convert: true,
	params: [{
			"name": "order_no",
			"title": "序号",
			"type": "number",
			"dataType": "mediumint"
		},
		{
			"name": "name",
			"title": "姓名\\日期",
			"type": "string",
			"dataType": "varchar",
			"string": {
				"notEmpty": 1
			}
		},
		{
			"name": "hoursAndDays",
			"title": "工时/天数",
			"type": "string",
			"dataType": "varchar"
		},
		{
			"name": "square",
			"title": "平方/",
			"type": "string",
			"dataType": "varchar"
		},
		{
			"name": "price",
			"title": "单价",
			"type": "number",
			"dataType": "double"
		},
		{
			"name": "confirm",
			"title": "签名确认",
			"type": "string",
			"dataType": "varchar"
		}
	],
	format: []
};

/**
 * 创建一个带模板的新表，并保存为test.xlsx
 */
async function test() {
	config.tpl = {
		head: "./tpl/count_head.xlsx",
		body: "./tpl/count_body.xlsx",
		foot: "./tpl/count_foot.xlsx"
	}
	var params = config.params;
	var pm = [];
	pm.push(params[0]);
	pm.push(params[1]);
	for (var i = 1; i <= 31; i++) {
		pm.push({
			"name": `day${i}`,
			"title": `${i}`,
			"type": "number",
			"dataType": "double"
		});
	}
	pm.push(params[2]);
	pm.push(params[3]);
	pm.push(params[4]);
	pm.push(params[5]);
	config.params = pm;
	var excel = new Excel(config);
	var jarr = "./data.json".loadJson();
	for (var i = 0; i < jarr.length; i++) {
		var o = jarr[i];
		o.order_no = i + 1;
		o.hoursAndDays = Math.round(o.hours).toFixed(2) + "/" + o.days;
		o.square = '';
		o.price = '';
		o.confirm = '';
	}

	excel.set_cell_func = function(cell, style) {
		var col = cell._column._number;
		if (col >= 3 && col <= 33) {
			var val = cell.value;
			if (val) {
				var arr = val.split(',');
				var value = arr[1];
				cell.value = value != '0' ? value : "-";
				if (!cell.style.font) {
					cell.style.font = {};
				}
				cell.style.font.name = "Arial";
				if (!cell.style.font.color) {
					cell.font.color = "FF000000";
				}
				if (arr[0] == "0.5") {
					cell.style.font.color.argb = "FFED7D31";
				} else if (arr[0] == "1") {
					cell.style.font.color.argb = "FF00B050";
				}
			} else {
				cell.value = "-"
			}
		}
	};
	var now = new Date();
	var year = now.toStr('yyyy');
	var month = now.toStr('MM');
	var rule = 1;
	excel.save_before = async function(sheet) {
		// 修改页头的时间，改成导出的年月
		var row_top = sheet.getRow(1);
		var cell = row_top.getCell(1);
		cell.value = now.toStr(cell.value);

		// 获取倒数第二行，并将其修改
		if (rule === 1 || rule === 2) {
			var count = sheet.rowCount;
			var row = sheet.getRow(count - 1);
			var value = row.getCell(1).value;
			var lt = value.richText;
			lt.splice(10, 4);
		}
	};
	await excel.save(jarr, null, "./test.xlsx");
	excel.set_cell_func = function() {
		
	}
	excel.save_before = async function() {
	
	}
	// var excel_foot = await excel.open("./tpl/count_foot.xlsx");
	// var sheet1 = Object.assign({}, excel.get_sheet());
	var sheet1 = await excel.open("./test.xlsx");
	var row = excel.add_row();
	row.height = 24;
	var sheet = excel.merge_sheet(excel.sheet, sheet1);
	var row = excel.add_row();
	row.height = 24;
	sheet = excel.merge_sheet(sheet, sheet1);
	excel.sheet = sheet;
	await excel.save(null, null, "./test.xlsx");
}


test();

==> mm_excel-1.1.3.tgz: package/test.js <==
const Excel = require('./index.js');

var config = {
	convert: true,
	params: [{
			"name": "order_no",
			"title": "序号",
			"type": "number",
			"dataType": "mediumint"
		},
		{
			"name": "name",
			"title": "姓名\\日期",
			"type": "string",
			"dataType": "varchar",
			"string": {
				"notEmpty": 1
			}
		},
		{
			"name": "hoursAndDays",
			"title": "工时/天数",
			"type": "string",
			"dataType": "varchar"
		},
		{
			"name": "square",
			"title": "平方/",
			"type": "string",
			"dataType": "varchar"
		},
		{
			"name": "price",
			"title": "单价",
			"type": "number",
			"dataType": "double"
		},
		{
			"name": "confirm",
			"title": "签名确认",
			"type": "string",
			"dataType": "varchar"
		}
	],
	format: []
};

/**
 * 创建一个带模板的新表，并保存为test.xlsx
 */
async function test() {
	config.tpl = {
		head: "./tpl/count_head.xlsx",
		body: "./tpl/count_body.xlsx",
		foot: "./tpl/count_foot.xlsx"
	}
	var params = config.params;
	var pm = [];
	pm.push(params[0]);
	pm.push(params[1]);
	for (var i = 1; i <= 31; i++) {
		pm.push({
			"name": `day${i}`,
			"title": `${i}`,
			"type": "number",
			"dataType": "double"
		});
	}
	pm.push(params[2]);
	pm.push(params[3]);
	pm.push(params[4]);
	pm.push(params[5]);
	config.params = pm;
	var excel = new Excel(config);
	var jarr = "./data.json".loadJson();
	for (var i = 0; i < jarr.length; i++) {
		var o = jarr[i];
		o.order_no = i + 1;
		o.hoursAndDays = o.hours.toFixed(2) + "/" + o.days;
		o.square = '';
		o.price = '';
		o.confirm = '';
	}

	excel.set_cell_func = function(cell, style) {
		var col = cell._column._number;
		if (col >= 3 && col <= 33) {
			var val = cell.value;
			cell.font = Object.assign({}, {
				name: style.font.name,
				size: style.font.size,
				color: Object.assign({}, style.font.color),
				charset: style.font.charset
			});
			if (val) {
				if (val == "0,0,0") {
					cell.value = '-';
					cell.font.color.argb = "FF333333";
				} else {
					var arr = val.split(',');
					var value = arr[1];
					cell.value = value !== '0' ? value : "0.00";
					cell.font.name = "Arial";
					if (arr[0] == "0.5") {
						cell.font.color.argb = "FFED7D31";
					} else if (arr[0] == "1") {
						cell.font.color.argb = "FF00B050";
					} else {
						cell.font.color.argb = "FF333333";
					}
				}
			} else {
				cell.font.color.argb = "FF333333";
				cell.value = "-"
			}
		}
	};
	var now = new Date();
	var year = now.toStr('yyyy');
	var month = now.toStr('MM');
	var rule = 1;
	excel.save_before = async function(sheet) {
		// 修改页头的时间，改成导出的年月
		var row_top = sheet.getRow(1);
		var cell = row_top.getCell(1);
		cell.value = now.toStr(cell.value);

		// 获取倒数第二行，并将其修改
		if (rule === 1 || rule === 2) {
			var count = sheet.rowCount;
			var row = sheet.getRow(count - 1);
			var value = row.getCell(1).value;
			var lt = value.richText;
			lt.splice(10, 2);
		}
	};
	await excel.save(jarr, null, "./test.xlsx");
	excel.set_cell_func = function() {
		
	}
	excel.save_before = async function() {
	
	}
	var sheet1 = await excel.open("./test.xlsx");
	var row = excel.add_row();
	row.height = 24;
	var sheet = excel.merge_sheet(excel.sheet, sheet1);
	var row = excel.add_row();
	row.height = 24;
	sheet = excel.merge_sheet(sheet, sheet1);
	excel.sheet = sheet;
	await excel.save(null, null, "./test.xlsx");
	
}


test();
